package biz

import (
	"context"

	"github.com/go-kratos/kratos/v2/log"

	"demo/internal/biz/common"
)

type ListCampaignRequest struct {
	common.PageRequest
	StartDate string `form:"start_date" json:"start_date"` // 开始时间
	EndDate   string `form:"end_date" json:"end_date"`     // 结束时间
}

type ListCampaignResponse struct {
	List     CampaignList     `json:"list"`      // 数据信息
	PageInfo *common.PageInfo `json:"page_info"` // 页码信息
}

type CampaignList []*Campaign

type Campaign struct {
	CampaignId   string `json:"campaign_id"`   // 广告组ID
	CampaignName string `json:"campaign_name"` // 广告主组名称
}

// CampaignRepo is a Report camRepo.
type CampaignRepo interface {
	List(ctx context.Context, customerId int64, req *ListCampaignRequest) (int64, CampaignList, error)
}

// ReportUsecase is a Report usecase.
type ReportUsecase struct {
	camRepo CampaignRepo
	log     *log.Helper
}

// NewReportUsecase new a Report usecase.
func NewReportUsecase(repo CampaignRepo, logger log.Logger) *ReportUsecase {
	return &ReportUsecase{camRepo: repo, log: log.NewHelper(logger)}
}

// ListCampaignData list campaign data.
func (p *ReportUsecase) ListCampaignData(ctx context.Context, customerId int64, req *ListCampaignRequest) (*ListCampaignResponse, error) {
	p.log.WithContext(ctx).Infof("req: %v", req)
	// todo 参数校验
	total, list, err := p.camRepo.List(ctx, customerId, req)
	if err != nil {
		return nil, err
	}
	return &ListCampaignResponse{
		List:     list,
		PageInfo: req.PageInfo(total),
	}, nil
}
